@@ -11,7 +11,6 @@ except:
 
 
 from .options import *
-from .settings import *
 
 
 if Path(sys.argv[0]).parts[-1] != 'qtstrap':
@@ -22,6 +21,12 @@ if Path(sys.argv[0]).parts[-1] != 'qtstrap':
             'No Qt Bindings found. Try "pip install PySide6" or "pip install PySide6"'
         ) from e
     else:
+        from .settings import *
+        
+        if OPTIONS.portable:
+            from .settings import PortableSettings as QSettings
+            QSettings._install()
+
         from .utils import *
         from .widgets import *
         from .base_application import (
